@@ -3,12 +3,13 @@ from __future__ import annotations
 from types import ModuleType
 from typing import Optional
 
-import dask
+import dask.config
 import urllib3
 from dask.distributed import Client, get_client
-from dask.utils import has_keyword
+from packaging.version import Version
 
 import coiled
+from coiled.compatibility import DISTRIBUTED_VERSION, register_plugin
 
 
 def register(client: Optional[Client] = None):
@@ -50,10 +51,10 @@ def register(client: Optional[Client] = None):
     exec(compiled, module.__dict__)
     plugin = module.CoiledTelemetry()  # type: ignore
 
-    if has_keyword(client.register_scheduler_plugin, "idempotent"):  # type: ignore
-        client.register_scheduler_plugin(plugin, idempotent=True)  # type: ignore
+    if DISTRIBUTED_VERSION >= Version("2022.05.1"):
+        register_plugin(client, plugin, idempotent=True)  # type: ignore
     else:
-        client.register_scheduler_plugin(plugin)  # type: ignore
+        register_plugin(client, plugin)  # type: ignore
 
 
 def list_clusters(
@@ -90,13 +91,19 @@ def list_clusters(
         return c.list_dask_scheduler(account=account, since=since, user=user)
 
 
-def list_computations(cluster_id: int, account: Optional[str] = None):
+def list_computations(
+    cluster_id: Optional[int] = None, scheduler_id: Optional[int] = None, account: Optional[str] = None
+):
     """List computations associated to a cluster
 
+    You need to specify either cluster_id or scheduler_id.
+
     Parameters
     ----------
-    cluster_id:
-        The identifier of the cluster that you want to select
+    cluster_id (optional):
+        The identifier of the Coiled cluster that you want to select
+    scheduler_id (optional):
+        The identifier of the (Coiled or non-Coiled) scheduler analytics that you want to select
     account:
         The account whose clusters you want to list
         You must be a member of this account
@@ -106,14 +113,14 @@ def list_computations(cluster_id: int, account: Optional[str] = None):
     --------
     >>> import coiled.analytics
     >>> clusters = coiled.analytics.list_clusters()  # doctest: +SKIP
-    >>> coiled.analytics.list_computations(clusters[0]["id"])  # doctest: +SKIP
+    >>> coiled.analytics.list_computations(scheduler_id=clusters[0]["id"])  # doctest: +SKIP
 
     See Also
     --------
     list_clusters
     """
     with coiled.Cloud() as c:
-        return c.list_computations(cluster_id, account=account)
+        return c.list_computations(cluster_id=cluster_id, scheduler_id=scheduler_id, account=account)
 
 
 def list_events(cluster_id: int, account: Optional[str] = None):
@@ -196,9 +203,9 @@ def list_exceptions(
         Optionally filter on username
         Providing ``None`` selects all users
     cluster_id (optional):
-        The identifier of the cluster that you want to select
+        The identifier of the Coiled cluster that you want to select
     scheduler_id (optional):
-        The identifier of the scheduler analytics that you want to select
+        The identifier of the (Coiled or non-Coiled) scheduler analytics that you want to select
 
     Examples
     --------
