@@ -25,6 +25,12 @@ def env():
 @env.command(context_settings=CONTEXT_SETTINGS)
 @click.option("-n", "--name", help="Name of software environment, it must be lowercase.")
 @click.option("--container", default=None, help="Base docker image to use.")
+@click.option(
+    "--ignore-container-entrypoint",
+    default=False,
+    help="Ignore the ENTRYPOINT when using specified container.",
+    is_flag=True,
+)
 @click.option(
     "--conda",
     default=None,
@@ -91,6 +97,7 @@ def env():
 def create(
     name,
     container,
+    ignore_container_entrypoint,
     conda,
     pip,
     force_rebuild,
@@ -117,6 +124,7 @@ def create(
             include_local_code=include_local_code,
             ignore_local_packages=ignore_local_package,
             enable_experimental_installer=enable_experimental_installer,
+            use_entrypoint=not ignore_container_entrypoint,
         )
     except BuildError as e:
         raise click.ClickException(f"{e}") from e
