@@ -108,6 +108,7 @@ if sys.version_info < (3, 10):
         def cleanup(self):
             if self._finalizer.detach() or os.path.exists(self.name):
                 self._rmtree(self.name, ignore_errors=self._ignore_cleanup_errors)
+
 else:
     TemporaryDirectory = TemporaryDirectoryBase
 
@@ -473,7 +474,7 @@ async def create_wheels_for_packages(
 
 pip_bad_req_regex = (
     r"(?P<package>.+) (?P<version>.+) has requirement "
-    r"(?P<requirement>.+), but you have (?P<requirement2>.+) (?P<reqversion>.+)."
+    r"(?P<requirement>.+), but you have (?P<requirement2>.+) (?P<reqversion>.+)\."
 )
 
 
@@ -503,12 +504,24 @@ async def check_pip_happy(progress: Optional[Progress] = None) -> Dict[str, List
 
 def _load_toml(path: Union[Path, str]) -> Dict:
     path = Path(path)
+    filename = path.name
+    dir_path = path.parent
+    if dir_path.exists():
+        dir_path = dir_path.resolve()
     toml_dict = {}
-    if path.exists():
+    # Walk up the directory tree to find the first toml file (up to 10 levels above)
+    for _ in range(10):
+        path = dir_path / filename
+        if not path.exists():
+            if dir_path == dir_path.parent:
+                break
+            dir_path = dir_path.parent
+            continue
         try:
             toml_dict = toml.load(path.open())
         except toml.TomlDecodeError as e:
             logger.debug(f"Failed to load {path}: {e}", exc_info=True)
+        break
     return toml_dict
 
 
