@@ -60,6 +60,7 @@ from coiled.exceptions import (
     GPUTypeError,
     InstanceTypeError,
     ParseIdentifierError,
+    PermissionsError,
     PortValidationError,
     UnsupportedBackendError,
 )
@@ -201,7 +202,9 @@ async def handle_api_exception(response, exception_cls: Type[Exception] = Server
         error_body = await response.json()
         if isinstance(error_body, dict):
             errs = error_body.get("non_field_errors")
-            if "message" in error_body:
+            if "aren't a member" in error_body.get("detail", ""):
+                raise PermissionsError(error_body["detail"])
+            elif "message" in error_body:
                 raise exception_cls(error_body["message"])
             elif errs and isinstance(errs, list) and len(errs):
                 raise exception_cls(errs[0])
