@@ -1,9 +1,7 @@
-from .._beta.cluster import ClusterBeta as Cluster
-from .._beta.core import AWSOptions, BackendOptions
-from .._beta.core import CloudBeta as Cloud
-from .._beta.core import (
-    FirewallOptions,
-    GCPOptions,
+from ..types import AWSOptions, BackendOptions, FirewallOptions, GCPOptions
+from .cluster import Cluster
+from .core import (
+    CloudV2,
     better_cluster_logs,
     cluster_details,
     cluster_logs,
@@ -15,16 +13,17 @@ from .._beta.core import (
 )
 
 __all__ = [
-    "Cloud",
-    "Cluster",
     "AWSOptions",
     "GCPOptions",
-    "better_cluster_logs",
-    "cluster_logs",
-    "BackendOptions",
     "FirewallOptions",
+    "BackendOptions",
+    "CloudV2",
+    "cluster_details",
+    "cluster_logs",
+    "Cluster",
+    "create_cluster",
+    "delete_cluster",
+    "list_clusters",
     "log_cluster_debug_info",
     "setup_logging",
-    "cluster_details",
-    "list_clusters",
 ]
