@@ -881,7 +881,11 @@ class CloudV2(OldCloud, Generic[IsAsynchronous]):
 
     async def _get_cluster_state(self, cluster_id: int, workspace: Optional[str] = None) -> dict:
         workspace = workspace or self.default_workspace
-        response = await self._do_request(
+        # Make request directly instead of using `_do_request` because we don't want any retries.
+        # Retry logic doesn't make sense because this is called by (frequent) period callback, so we'll just wait
+        # for next periodic callback call, otherwise retries will overlap with the periodic callback and build up.
+        session = self._ensure_session()
+        response = await session.request(
             "GET", self.server + f"/api/v2/clusters/account/{workspace}/id/{cluster_id}/state"
         )
         if response.status >= 400:
